mathtools.NegativeInfinity
==========================

.. abjad-lineage:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity

.. autoclass:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__eq__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__format__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__ge__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__gt__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__hash__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__le__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__lt__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__ne__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__repr__
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__sub__

Bases
-----

- :py:class:`mathtools.Infinity <abjad.tools.mathtools.Infinity.Infinity>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__format__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__repr__
   :noindex:

.. automethod:: abjad.tools.mathtools.NegativeInfinity.NegativeInfinity.__sub__
   :noindex:
